@@ -10,7 +10,7 @@ Usage::
     ```
 """
 import sys
-from typing import Dict, List
+from typing import IO, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -416,7 +416,7 @@ GetGraphqlApiResponseTypeDef = TypedDict(
 )
 
 GetIntrospectionSchemaResponseTypeDef = TypedDict(
-    "GetIntrospectionSchemaResponseTypeDef", {"schema": bytes}, total=False
+    "GetIntrospectionSchemaResponseTypeDef", {"schema": Union[bytes, IO[bytes]]}, total=False
 )
 
 GetResolverResponseTypeDef = TypedDict(
